FloatMeta

Struct FloatMeta 

pub struct FloatMeta<D: Device> {
    pub op: Option<Op<D>>,
    pub requires_grad: RwLock<bool>,
}

Fields

op: Option<Op<D>>requires_grad: RwLock<bool>

Implementations

Source

impl<D: Device> FloatMeta<D>

pub fn var() -> Self

A leaf variable that accumulates gradients.

pub fn val() -> Self

A constant value that does not track gradients.

pub fn from_op(op: Op<D>) -> Self

A non-leaf node produced by op.

pub fn op(&self) -> Option<&Op<D>>

pub fn requires_grad(&self) -> bool

pub fn set_requires_grad(&self, mode: bool)

pub fn is_leaf(&self) -> bool

A tensor is a leaf when it requires grad but was not produced by an op.

Source

impl<D: Device> FloatMeta<D>

Records an op into a FloatMeta iff grad is globally enabled and record is true (i.e. some input requires grad). Otherwise produces a plain value meta.

pub fn on_binary( lhs: &Tensor<D, Float>, rhs: &Tensor<D, Float>, op: BinaryOp, ) -> Self

pub fn on_binary_scalar(lhs: &Tensor<D, Float>, rhs: f64, op: BinaryOp) -> Self

pub fn on_unary(t: &Tensor<D, Float>, op: UnaryOp<f64>) -> Self

pub fn on_float_unary(t: &Tensor<D, Float>, op: FloatUnaryOp) -> Self

pub fn on_broadcast(t: &Tensor<D, Float>) -> Self

pub fn on_reduce(t: &Tensor<D, Float>, dims: &[usize], op: ReduceOp) -> Self

pub fn on_matmul(lhs: &Tensor<D, Float>, rhs: &Tensor<D, Float>) -> Self

pub fn on_narrow( t: &Tensor<D, Float>, dim: usize, start: usize, len: usize, ) -> Self

pub fn on_slice( t: &Tensor<D, Float>, dim: usize, start: usize, end: usize, step: usize, ) -> Self

pub fn on_reshape(t: &Tensor<D, Float>) -> Self

pub fn on_transpose(t: &Tensor<D, Float>, dim1: usize, dim2: usize) -> Self

pub fn on_permute(t: &Tensor<D, Float>, dims: Vec<usize>) -> Self

pub fn on_cat<A: AsRef<Tensor<D, Float>>>(args: &[A], dim: usize) -> Self

pub fn on_copy(t: &Tensor<D, Float>) -> Self

pub fn on_cast(t: &Tensor<D, Float>) -> Self

pub fn on_pick( mask: &Tensor<D, Bool>, tv: Option<&Tensor<D, Float>>, fv: Option<&Tensor<D, Float>>, ) -> Self

pub fn on_index_select( t: &Tensor<D, Float>, idx: &Tensor<D, Int>, dim: usize, ) -> Self

pub fn on_index_add( init: &Tensor<D, Float>, idx: &Tensor<D, Int>, src: &Tensor<D, Float>, dim: usize, ) -> Self

pub fn on_scatter_add( init: &Tensor<D, Float>, idx: &Tensor<D, Int>, src: &Tensor<D, Float>, dim: usize, ) -> Self

pub fn on_gather( src: &Tensor<D, Float>, idx: &Tensor<D, Int>, dim: usize, ) -> Self

pub fn on_rms_norm( input: &Tensor<D, Float>, weight: &Tensor<D, Float>, eps: f64, ) -> Self

pub fn on_softmax(input: &Tensor<D, Float>, dim: usize) -> Self